@@ -303,6 +303,9 @@ def friendly_http_error(func):
         "forbidden": exceptions.NotAllowed,
         "duplicate": exceptions.AlreadyExists,
         "push.webhookUrlUnauthorized": exceptions.PushWebhookInvalid,
+        "channelIdNotUnique": exceptions.ChannelIdNotUnique,
+        "notACalendarUser": exceptions.NotACalendarUser,
+        "quotaExceeded": exceptions.QuotaExceeded,
     }
     _statuses = {
         "INVALID_ARGUMENT": exceptions.ValidationError,
