@@ -51,3 +51,15 @@ class MissingUserIdentification(Exception):
 
 class PushWebhookInvalid(ValidationError):
     pass
+
+
+class ChannelIdNotUnique(Exception):
+    pass
+
+
+class NotACalendarUser(Exception):
+    pass
+
+
+class QuotaExceeded(Exception):
+    pass
